pub fn initialize_logging(
app_name: &'static str,
) -> Result<Arc<SuperConsole<Stdout, Stderr>>, LisaError>Expand description
Initialize the Lisa logger, this will error if we run into any errors actually setting up everything that needs to be set-up.
Errors
If we cannot determine which crate::display::renderers::ConsoleRenderer
to utilize.